Documentation
¶
Index ¶
- func ComputeHttpsHealthCheck_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func ComputeHttpsHealthCheck_IsConstruct(x interface{}) *bool
- func ComputeHttpsHealthCheck_IsTerraformElement(x interface{}) *bool
- func ComputeHttpsHealthCheck_IsTerraformResource(x interface{}) *bool
- func ComputeHttpsHealthCheck_TfResourceType() *string
- func NewComputeHttpsHealthCheckTimeoutsOutputReference_Override(c ComputeHttpsHealthCheckTimeoutsOutputReference, ...)
- func NewComputeHttpsHealthCheck_Override(c ComputeHttpsHealthCheck, scope constructs.Construct, id *string, ...)
- type ComputeHttpsHealthCheck
- type ComputeHttpsHealthCheckConfig
- type ComputeHttpsHealthCheckTimeouts
- type ComputeHttpsHealthCheckTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ComputeHttpsHealthCheck_GenerateConfigForImport ¶
func ComputeHttpsHealthCheck_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a ComputeHttpsHealthCheck resource upon running "cdktf plan <stack-name>".
func ComputeHttpsHealthCheck_IsConstruct ¶
func ComputeHttpsHealthCheck_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ComputeHttpsHealthCheck_IsTerraformElement ¶
func ComputeHttpsHealthCheck_IsTerraformElement(x interface{}) *bool
Experimental.
func ComputeHttpsHealthCheck_IsTerraformResource ¶
func ComputeHttpsHealthCheck_IsTerraformResource(x interface{}) *bool
Experimental.
func ComputeHttpsHealthCheck_TfResourceType ¶
func ComputeHttpsHealthCheck_TfResourceType() *string
func NewComputeHttpsHealthCheckTimeoutsOutputReference_Override ¶
func NewComputeHttpsHealthCheckTimeoutsOutputReference_Override(c ComputeHttpsHealthCheckTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComputeHttpsHealthCheck_Override ¶
func NewComputeHttpsHealthCheck_Override(c ComputeHttpsHealthCheck, scope constructs.Construct, id *string, config *ComputeHttpsHealthCheckConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/compute_https_health_check google_compute_https_health_check} Resource.
Types ¶
type ComputeHttpsHealthCheck ¶
type ComputeHttpsHealthCheck interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
CheckIntervalSec() *float64
SetCheckIntervalSec(val *float64)
CheckIntervalSecInput() *float64
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreationTimestamp() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HealthyThreshold() *float64
SetHealthyThreshold(val *float64)
HealthyThresholdInput() *float64
Host() *string
SetHost(val *string)
HostInput() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Port() *float64
SetPort(val *float64)
PortInput() *float64
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RequestPath() *string
SetRequestPath(val *string)
RequestPathInput() *string
SelfLink() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() ComputeHttpsHealthCheckTimeoutsOutputReference
TimeoutSec() *float64
SetTimeoutSec(val *float64)
TimeoutSecInput() *float64
TimeoutsInput() interface{}
UnhealthyThreshold() *float64
SetUnhealthyThreshold(val *float64)
UnhealthyThresholdInput() *float64
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *ComputeHttpsHealthCheckTimeouts)
ResetCheckIntervalSec()
ResetDescription()
ResetHealthyThreshold()
ResetHost()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPort()
ResetProject()
ResetRequestPath()
ResetTimeouts()
ResetTimeoutSec()
ResetUnhealthyThreshold()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/compute_https_health_check google_compute_https_health_check}.
func NewComputeHttpsHealthCheck ¶
func NewComputeHttpsHealthCheck(scope constructs.Construct, id *string, config *ComputeHttpsHealthCheckConfig) ComputeHttpsHealthCheck
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/compute_https_health_check google_compute_https_health_check} Resource.
type ComputeHttpsHealthCheckConfig ¶
type ComputeHttpsHealthCheckConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Name of the resource.
//
// Provided by the client when the resource is
// created. The name must be 1-63 characters long, and comply with
// RFC1035. Specifically, the name must be 1-63 characters long and
// match the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means
// the first character must be a lowercase letter, and all following
// characters must be a dash, lowercase letter, or digit, except the
// last character, which cannot be a dash.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/compute_https_health_check#name ComputeHttpsHealthCheck#name}
Name *string `field:"required" json:"name" yaml:"name"`
// How often (in seconds) to send a health check. The default value is 5 seconds.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/compute_https_health_check#check_interval_sec ComputeHttpsHealthCheck#check_interval_sec}
CheckIntervalSec *float64 `field:"optional" json:"checkIntervalSec" yaml:"checkIntervalSec"`
// An optional description of this resource. Provide this property when you create the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/compute_https_health_check#description ComputeHttpsHealthCheck#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// A so-far unhealthy instance will be marked healthy after this many consecutive successes. The default value is 2.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/compute_https_health_check#healthy_threshold ComputeHttpsHealthCheck#healthy_threshold}
HealthyThreshold *float64 `field:"optional" json:"healthyThreshold" yaml:"healthyThreshold"`
// The value of the host header in the HTTPS health check request.
//
// If
// left empty (default value), the public IP on behalf of which this
// health check is performed will be used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/compute_https_health_check#host ComputeHttpsHealthCheck#host}
Host *string `field:"optional" json:"host" yaml:"host"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/compute_https_health_check#id ComputeHttpsHealthCheck#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// The TCP port number for the HTTPS health check request. The default value is 443.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/compute_https_health_check#port ComputeHttpsHealthCheck#port}
Port *float64 `field:"optional" json:"port" yaml:"port"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/compute_https_health_check#project ComputeHttpsHealthCheck#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// The request path of the HTTPS health check request. The default value is /.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/compute_https_health_check#request_path ComputeHttpsHealthCheck#request_path}
RequestPath *string `field:"optional" json:"requestPath" yaml:"requestPath"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/compute_https_health_check#timeouts ComputeHttpsHealthCheck#timeouts}
Timeouts *ComputeHttpsHealthCheckTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// How long (in seconds) to wait before claiming failure.
//
// The default value is 5 seconds. It is invalid for timeoutSec to have
// greater value than checkIntervalSec.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/compute_https_health_check#timeout_sec ComputeHttpsHealthCheck#timeout_sec}
TimeoutSec *float64 `field:"optional" json:"timeoutSec" yaml:"timeoutSec"`
// A so-far healthy instance will be marked unhealthy after this many consecutive failures. The default value is 2.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/compute_https_health_check#unhealthy_threshold ComputeHttpsHealthCheck#unhealthy_threshold}
UnhealthyThreshold *float64 `field:"optional" json:"unhealthyThreshold" yaml:"unhealthyThreshold"`
}
type ComputeHttpsHealthCheckTimeouts ¶
type ComputeHttpsHealthCheckTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/compute_https_health_check#create ComputeHttpsHealthCheck#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/compute_https_health_check#delete ComputeHttpsHealthCheck#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/compute_https_health_check#update ComputeHttpsHealthCheck#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type ComputeHttpsHealthCheckTimeoutsOutputReference ¶
type ComputeHttpsHealthCheckTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComputeHttpsHealthCheckTimeoutsOutputReference ¶
func NewComputeHttpsHealthCheckTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComputeHttpsHealthCheckTimeoutsOutputReference