Documentation
¶
Index ¶
- func MemcacheInstance_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func MemcacheInstance_IsConstruct(x interface{}) *bool
- func MemcacheInstance_IsTerraformElement(x interface{}) *bool
- func MemcacheInstance_IsTerraformResource(x interface{}) *bool
- func MemcacheInstance_TfResourceType() *string
- func NewMemcacheInstanceMaintenancePolicyOutputReference_Override(m MemcacheInstanceMaintenancePolicyOutputReference, ...)
- func NewMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList_Override(m MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList, ...)
- func NewMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference_Override(m MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference, ...)
- func NewMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference_Override(...)
- func NewMemcacheInstanceMaintenanceScheduleList_Override(m MemcacheInstanceMaintenanceScheduleList, ...)
- func NewMemcacheInstanceMaintenanceScheduleOutputReference_Override(m MemcacheInstanceMaintenanceScheduleOutputReference, ...)
- func NewMemcacheInstanceMemcacheNodesList_Override(m MemcacheInstanceMemcacheNodesList, ...)
- func NewMemcacheInstanceMemcacheNodesOutputReference_Override(m MemcacheInstanceMemcacheNodesOutputReference, ...)
- func NewMemcacheInstanceMemcacheParametersOutputReference_Override(m MemcacheInstanceMemcacheParametersOutputReference, ...)
- func NewMemcacheInstanceNodeConfigOutputReference_Override(m MemcacheInstanceNodeConfigOutputReference, ...)
- func NewMemcacheInstanceTimeoutsOutputReference_Override(m MemcacheInstanceTimeoutsOutputReference, ...)
- func NewMemcacheInstance_Override(m MemcacheInstance, scope constructs.Construct, id *string, ...)
- type MemcacheInstance
- type MemcacheInstanceConfig
- type MemcacheInstanceMaintenancePolicy
- type MemcacheInstanceMaintenancePolicyOutputReference
- type MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindow
- type MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList
- type MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference
- type MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime
- type MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference
- type MemcacheInstanceMaintenanceSchedule
- type MemcacheInstanceMaintenanceScheduleList
- type MemcacheInstanceMaintenanceScheduleOutputReference
- type MemcacheInstanceMemcacheNodes
- type MemcacheInstanceMemcacheNodesList
- type MemcacheInstanceMemcacheNodesOutputReference
- type MemcacheInstanceMemcacheParameters
- type MemcacheInstanceMemcacheParametersOutputReference
- type MemcacheInstanceNodeConfig
- type MemcacheInstanceNodeConfigOutputReference
- type MemcacheInstanceTimeouts
- type MemcacheInstanceTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MemcacheInstance_GenerateConfigForImport ¶
func MemcacheInstance_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a MemcacheInstance resource upon running "cdktf plan <stack-name>".
func MemcacheInstance_IsConstruct ¶
func MemcacheInstance_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func MemcacheInstance_IsTerraformElement ¶
func MemcacheInstance_IsTerraformElement(x interface{}) *bool
Experimental.
func MemcacheInstance_IsTerraformResource ¶
func MemcacheInstance_IsTerraformResource(x interface{}) *bool
Experimental.
func MemcacheInstance_TfResourceType ¶
func MemcacheInstance_TfResourceType() *string
func NewMemcacheInstanceMaintenancePolicyOutputReference_Override ¶
func NewMemcacheInstanceMaintenancePolicyOutputReference_Override(m MemcacheInstanceMaintenancePolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList_Override ¶
func NewMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList_Override(m MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference_Override ¶
func NewMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference_Override(m MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference_Override ¶
func NewMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference_Override(m MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewMemcacheInstanceMaintenanceScheduleList_Override ¶
func NewMemcacheInstanceMaintenanceScheduleList_Override(m MemcacheInstanceMaintenanceScheduleList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewMemcacheInstanceMaintenanceScheduleOutputReference_Override ¶
func NewMemcacheInstanceMaintenanceScheduleOutputReference_Override(m MemcacheInstanceMaintenanceScheduleOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewMemcacheInstanceMemcacheNodesList_Override ¶
func NewMemcacheInstanceMemcacheNodesList_Override(m MemcacheInstanceMemcacheNodesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewMemcacheInstanceMemcacheNodesOutputReference_Override ¶
func NewMemcacheInstanceMemcacheNodesOutputReference_Override(m MemcacheInstanceMemcacheNodesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewMemcacheInstanceMemcacheParametersOutputReference_Override ¶
func NewMemcacheInstanceMemcacheParametersOutputReference_Override(m MemcacheInstanceMemcacheParametersOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewMemcacheInstanceNodeConfigOutputReference_Override ¶
func NewMemcacheInstanceNodeConfigOutputReference_Override(m MemcacheInstanceNodeConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewMemcacheInstanceTimeoutsOutputReference_Override ¶
func NewMemcacheInstanceTimeoutsOutputReference_Override(m MemcacheInstanceTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewMemcacheInstance_Override ¶
func NewMemcacheInstance_Override(m MemcacheInstance, scope constructs.Construct, id *string, config *MemcacheInstanceConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance google_memcache_instance} Resource.
Types ¶
type MemcacheInstance ¶
type MemcacheInstance interface {
cdktf.TerraformResource
AuthorizedNetwork() *string
SetAuthorizedNetwork(val *string)
AuthorizedNetworkInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DiscoveryEndpoint() *string
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
EffectiveLabels() cdktf.StringMap
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MaintenancePolicy() MemcacheInstanceMaintenancePolicyOutputReference
MaintenancePolicyInput() *MemcacheInstanceMaintenancePolicy
MaintenanceSchedule() MemcacheInstanceMaintenanceScheduleList
MemcacheFullVersion() *string
MemcacheNodes() MemcacheInstanceMemcacheNodesList
MemcacheParameters() MemcacheInstanceMemcacheParametersOutputReference
MemcacheParametersInput() *MemcacheInstanceMemcacheParameters
MemcacheVersion() *string
SetMemcacheVersion(val *string)
MemcacheVersionInput() *string
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
NodeConfig() MemcacheInstanceNodeConfigOutputReference
NodeConfigInput() *MemcacheInstanceNodeConfig
NodeCount() *float64
SetNodeCount(val *float64)
NodeCountInput() *float64
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Region() *string
SetRegion(val *string)
RegionInput() *string
ReservedIpRangeId() *[]*string
SetReservedIpRangeId(val *[]*string)
ReservedIpRangeIdInput() *[]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() MemcacheInstanceTimeoutsOutputReference
TimeoutsInput() interface{}
Zones() *[]*string
SetZones(val *[]*string)
ZonesInput() *[]*string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutMaintenancePolicy(value *MemcacheInstanceMaintenancePolicy)
PutMemcacheParameters(value *MemcacheInstanceMemcacheParameters)
PutNodeConfig(value *MemcacheInstanceNodeConfig)
PutTimeouts(value *MemcacheInstanceTimeouts)
ResetAuthorizedNetwork()
ResetDisplayName()
ResetId()
ResetLabels()
ResetMaintenancePolicy()
ResetMemcacheParameters()
ResetMemcacheVersion()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetRegion()
ResetReservedIpRangeId()
ResetTimeouts()
ResetZones()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance google_memcache_instance}.
func NewMemcacheInstance ¶
func NewMemcacheInstance(scope constructs.Construct, id *string, config *MemcacheInstanceConfig) MemcacheInstance
Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance google_memcache_instance} Resource.
type MemcacheInstanceConfig ¶
type MemcacheInstanceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The resource name of the instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#name MemcacheInstance#name}
Name *string `field:"required" json:"name" yaml:"name"`
// node_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#node_config MemcacheInstance#node_config}
NodeConfig *MemcacheInstanceNodeConfig `field:"required" json:"nodeConfig" yaml:"nodeConfig"`
// Number of nodes in the memcache instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#node_count MemcacheInstance#node_count}
NodeCount *float64 `field:"required" json:"nodeCount" yaml:"nodeCount"`
// The full name of the GCE network to connect the instance to. If not provided, 'default' will be used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#authorized_network MemcacheInstance#authorized_network}
AuthorizedNetwork *string `field:"optional" json:"authorizedNetwork" yaml:"authorizedNetwork"`
// A user-visible name for the instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#display_name MemcacheInstance#display_name}
DisplayName *string `field:"optional" json:"displayName" yaml:"displayName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#id MemcacheInstance#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Resource labels to represent user-provided metadata.
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field 'effective_labels' for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#labels MemcacheInstance#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// maintenance_policy block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#maintenance_policy MemcacheInstance#maintenance_policy}
MaintenancePolicy *MemcacheInstanceMaintenancePolicy `field:"optional" json:"maintenancePolicy" yaml:"maintenancePolicy"`
// memcache_parameters block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#memcache_parameters MemcacheInstance#memcache_parameters}
MemcacheParameters *MemcacheInstanceMemcacheParameters `field:"optional" json:"memcacheParameters" yaml:"memcacheParameters"`
// The major version of Memcached software.
//
// If not provided, latest supported version will be used.
// Currently the latest supported major version is MEMCACHE_1_5. The minor version will be automatically
// determined by our system based on the latest supported minor version. Default value: "MEMCACHE_1_5" Possible values: ["MEMCACHE_1_5", "MEMCACHE_1_6_15"]
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#memcache_version MemcacheInstance#memcache_version}
MemcacheVersion *string `field:"optional" json:"memcacheVersion" yaml:"memcacheVersion"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#project MemcacheInstance#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// The region of the Memcache instance. If it is not provided, the provider region is used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#region MemcacheInstance#region}
Region *string `field:"optional" json:"region" yaml:"region"`
// Contains the name of allocated IP address ranges associated with the private service access connection for example, "test-default" associated with IP range 10.0.0.0/29.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#reserved_ip_range_id MemcacheInstance#reserved_ip_range_id}
ReservedIpRangeId *[]*string `field:"optional" json:"reservedIpRangeId" yaml:"reservedIpRangeId"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#timeouts MemcacheInstance#timeouts}
Timeouts *MemcacheInstanceTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Zones where memcache nodes should be provisioned. If not provided, all zones will be used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#zones MemcacheInstance#zones}
Zones *[]*string `field:"optional" json:"zones" yaml:"zones"`
}
type MemcacheInstanceMaintenancePolicy ¶
type MemcacheInstanceMaintenancePolicy struct {
// weekly_maintenance_window block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#weekly_maintenance_window MemcacheInstance#weekly_maintenance_window}
WeeklyMaintenanceWindow interface{} `field:"required" json:"weeklyMaintenanceWindow" yaml:"weeklyMaintenanceWindow"`
// Optional. Description of what this policy is for. Create/Update methods return INVALID_ARGUMENT if the length is greater than 512.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#description MemcacheInstance#description}
Description *string `field:"optional" json:"description" yaml:"description"`
}
type MemcacheInstanceMaintenancePolicyOutputReference ¶
type MemcacheInstanceMaintenancePolicyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CreateTime() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
Fqn() *string
InternalValue() *MemcacheInstanceMaintenancePolicy
SetInternalValue(val *MemcacheInstanceMaintenancePolicy)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UpdateTime() *string
WeeklyMaintenanceWindow() MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList
WeeklyMaintenanceWindowInput() interface{}
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutWeeklyMaintenanceWindow(value interface{})
ResetDescription()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewMemcacheInstanceMaintenancePolicyOutputReference ¶
func NewMemcacheInstanceMaintenancePolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) MemcacheInstanceMaintenancePolicyOutputReference
type MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindow ¶
type MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindow struct {
// Required.
//
// The day of week that maintenance updates occur.
// - DAY_OF_WEEK_UNSPECIFIED: The day of the week is unspecified.
// - MONDAY: Monday
// - TUESDAY: Tuesday
// - WEDNESDAY: Wednesday
// - THURSDAY: Thursday
// - FRIDAY: Friday
// - SATURDAY: Saturday
// - SUNDAY: Sunday Possible values: ["DAY_OF_WEEK_UNSPECIFIED", "MONDAY", "TUESDAY", "WEDNESDAY", "THURSDAY", "FRIDAY", "SATURDAY", "SUNDAY"]
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#day MemcacheInstance#day}
Day *string `field:"required" json:"day" yaml:"day"`
// Required.
//
// The length of the maintenance window, ranging from 3 hours to 8 hours.
// A duration in seconds with up to nine fractional digits,
// terminated by 's'. Example: "3.5s".
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#duration MemcacheInstance#duration}
Duration *string `field:"required" json:"duration" yaml:"duration"`
// start_time block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#start_time MemcacheInstance#start_time}
StartTime *MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime `field:"required" json:"startTime" yaml:"startTime"`
}
type MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList ¶
type MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList ¶
func NewMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList
type MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference ¶
type MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Day() *string
SetDay(val *string)
DayInput() *string
Duration() *string
SetDuration(val *string)
DurationInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
StartTime() MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference
StartTimeInput() *MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutStartTime(value *MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference ¶
func NewMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference
type MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime ¶
type MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime struct {
// Hours of day in 24 hour format.
//
// Should be from 0 to 23.
// An API may choose to allow the value "24:00:00" for scenarios like business closing time.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#hours MemcacheInstance#hours}
Hours *float64 `field:"optional" json:"hours" yaml:"hours"`
// Minutes of hour of day. Must be from 0 to 59.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#minutes MemcacheInstance#minutes}
Minutes *float64 `field:"optional" json:"minutes" yaml:"minutes"`
// Fractions of seconds in nanoseconds. Must be from 0 to 999,999,999.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#nanos MemcacheInstance#nanos}
Nanos *float64 `field:"optional" json:"nanos" yaml:"nanos"`
// Seconds of minutes of the time.
//
// Must normally be from 0 to 59.
// An API may allow the value 60 if it allows leap-seconds.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#seconds MemcacheInstance#seconds}
Seconds *float64 `field:"optional" json:"seconds" yaml:"seconds"`
}
type MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference ¶
type MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Hours() *float64
SetHours(val *float64)
HoursInput() *float64
InternalValue() *MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime
SetInternalValue(val *MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime)
Minutes() *float64
SetMinutes(val *float64)
MinutesInput() *float64
Nanos() *float64
SetNanos(val *float64)
NanosInput() *float64
Seconds() *float64
SetSeconds(val *float64)
SecondsInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetHours()
ResetMinutes()
ResetNanos()
ResetSeconds()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference ¶
func NewMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference
type MemcacheInstanceMaintenanceSchedule ¶
type MemcacheInstanceMaintenanceSchedule struct {
}
type MemcacheInstanceMaintenanceScheduleList ¶
type MemcacheInstanceMaintenanceScheduleList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) MemcacheInstanceMaintenanceScheduleOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewMemcacheInstanceMaintenanceScheduleList ¶
func NewMemcacheInstanceMaintenanceScheduleList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) MemcacheInstanceMaintenanceScheduleList
type MemcacheInstanceMaintenanceScheduleOutputReference ¶
type MemcacheInstanceMaintenanceScheduleOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EndTime() *string
// Experimental.
Fqn() *string
InternalValue() *MemcacheInstanceMaintenanceSchedule
SetInternalValue(val *MemcacheInstanceMaintenanceSchedule)
ScheduleDeadlineTime() *string
StartTime() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewMemcacheInstanceMaintenanceScheduleOutputReference ¶
func NewMemcacheInstanceMaintenanceScheduleOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) MemcacheInstanceMaintenanceScheduleOutputReference
type MemcacheInstanceMemcacheNodes ¶
type MemcacheInstanceMemcacheNodes struct {
}
type MemcacheInstanceMemcacheNodesList ¶
type MemcacheInstanceMemcacheNodesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) MemcacheInstanceMemcacheNodesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewMemcacheInstanceMemcacheNodesList ¶
func NewMemcacheInstanceMemcacheNodesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) MemcacheInstanceMemcacheNodesList
type MemcacheInstanceMemcacheNodesOutputReference ¶
type MemcacheInstanceMemcacheNodesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Host() *string
InternalValue() *MemcacheInstanceMemcacheNodes
SetInternalValue(val *MemcacheInstanceMemcacheNodes)
NodeId() *string
Port() *float64
State() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Zone() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewMemcacheInstanceMemcacheNodesOutputReference ¶
func NewMemcacheInstanceMemcacheNodesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) MemcacheInstanceMemcacheNodesOutputReference
type MemcacheInstanceMemcacheParameters ¶
type MemcacheInstanceMemcacheParameters struct {
// User-defined set of parameters to use in the memcache process.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#params MemcacheInstance#params}
Params *map[string]*string `field:"optional" json:"params" yaml:"params"`
}
type MemcacheInstanceMemcacheParametersOutputReference ¶
type MemcacheInstanceMemcacheParametersOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *MemcacheInstanceMemcacheParameters
SetInternalValue(val *MemcacheInstanceMemcacheParameters)
Params() *map[string]*string
SetParams(val *map[string]*string)
ParamsInput() *map[string]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetParams()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewMemcacheInstanceMemcacheParametersOutputReference ¶
func NewMemcacheInstanceMemcacheParametersOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) MemcacheInstanceMemcacheParametersOutputReference
type MemcacheInstanceNodeConfig ¶
type MemcacheInstanceNodeConfig struct {
// Number of CPUs per node.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#cpu_count MemcacheInstance#cpu_count}
CpuCount *float64 `field:"required" json:"cpuCount" yaml:"cpuCount"`
// Memory size in Mebibytes for each memcache node.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#memory_size_mb MemcacheInstance#memory_size_mb}
MemorySizeMb *float64 `field:"required" json:"memorySizeMb" yaml:"memorySizeMb"`
}
type MemcacheInstanceNodeConfigOutputReference ¶
type MemcacheInstanceNodeConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CpuCount() *float64
SetCpuCount(val *float64)
CpuCountInput() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *MemcacheInstanceNodeConfig
SetInternalValue(val *MemcacheInstanceNodeConfig)
MemorySizeMb() *float64
SetMemorySizeMb(val *float64)
MemorySizeMbInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewMemcacheInstanceNodeConfigOutputReference ¶
func NewMemcacheInstanceNodeConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) MemcacheInstanceNodeConfigOutputReference
type MemcacheInstanceTimeouts ¶
type MemcacheInstanceTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#create MemcacheInstance#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#delete MemcacheInstance#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.32.0/docs/resources/memcache_instance#update MemcacheInstance#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type MemcacheInstanceTimeoutsOutputReference ¶
type MemcacheInstanceTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewMemcacheInstanceTimeoutsOutputReference ¶
func NewMemcacheInstanceTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) MemcacheInstanceTimeoutsOutputReference
Source Files
¶
- MemcacheInstanceConfig.go
- MemcacheInstanceMaintenancePolicy.go
- MemcacheInstanceMaintenancePolicyOutputReference.go
- MemcacheInstanceMaintenancePolicyOutputReference__checks.go
- MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindow.go
- MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList.go
- MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList__checks.go
- MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference.go
- MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference__checks.go
- MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime.go
- MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference.go
- MemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference__checks.go
- MemcacheInstanceMaintenanceSchedule.go
- MemcacheInstanceMaintenanceScheduleList.go
- MemcacheInstanceMaintenanceScheduleList__checks.go
- MemcacheInstanceMaintenanceScheduleOutputReference.go
- MemcacheInstanceMaintenanceScheduleOutputReference__checks.go
- MemcacheInstanceMemcacheNodes.go
- MemcacheInstanceMemcacheNodesList.go
- MemcacheInstanceMemcacheNodesList__checks.go
- MemcacheInstanceMemcacheNodesOutputReference.go
- MemcacheInstanceMemcacheNodesOutputReference__checks.go
- MemcacheInstanceMemcacheParameters.go
- MemcacheInstanceMemcacheParametersOutputReference.go
- MemcacheInstanceMemcacheParametersOutputReference__checks.go
- MemcacheInstanceNodeConfig.go
- MemcacheInstanceNodeConfigOutputReference.go
- MemcacheInstanceNodeConfigOutputReference__checks.go
- MemcacheInstanceTimeouts.go
- MemcacheInstanceTimeoutsOutputReference.go
- MemcacheInstanceTimeoutsOutputReference__checks.go
- MemcacheInstance__checks.go
- main.go
- memcacheinstance.go