Documentation
¶
Index ¶
- func DataPostgresqlSequences_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func DataPostgresqlSequences_IsConstruct(x interface{}) *bool
- func DataPostgresqlSequences_IsTerraformDataSource(x interface{}) *bool
- func DataPostgresqlSequences_IsTerraformElement(x interface{}) *bool
- func DataPostgresqlSequences_TfResourceType() *string
- func NewDataPostgresqlSequencesSequencesList_Override(d DataPostgresqlSequencesSequencesList, ...)
- func NewDataPostgresqlSequencesSequencesOutputReference_Override(d DataPostgresqlSequencesSequencesOutputReference, ...)
- func NewDataPostgresqlSequences_Override(d DataPostgresqlSequences, scope constructs.Construct, id *string, ...)
- type DataPostgresqlSequences
- type DataPostgresqlSequencesConfig
- type DataPostgresqlSequencesSequences
- type DataPostgresqlSequencesSequencesList
- type DataPostgresqlSequencesSequencesOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataPostgresqlSequences_GenerateConfigForImport ¶
func DataPostgresqlSequences_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a DataPostgresqlSequences resource upon running "cdktf plan <stack-name>".
func DataPostgresqlSequences_IsConstruct ¶
func DataPostgresqlSequences_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataPostgresqlSequences_IsTerraformDataSource ¶
func DataPostgresqlSequences_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataPostgresqlSequences_IsTerraformElement ¶
func DataPostgresqlSequences_IsTerraformElement(x interface{}) *bool
Experimental.
func DataPostgresqlSequences_TfResourceType ¶
func DataPostgresqlSequences_TfResourceType() *string
func NewDataPostgresqlSequencesSequencesList_Override ¶
func NewDataPostgresqlSequencesSequencesList_Override(d DataPostgresqlSequencesSequencesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataPostgresqlSequencesSequencesOutputReference_Override ¶
func NewDataPostgresqlSequencesSequencesOutputReference_Override(d DataPostgresqlSequencesSequencesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataPostgresqlSequences_Override ¶
func NewDataPostgresqlSequences_Override(d DataPostgresqlSequences, scope constructs.Construct, id *string, config *DataPostgresqlSequencesConfig)
Create a new {@link https://registry.terraform.io/providers/cyrilgdn/postgresql/1.25.0/docs/data-sources/sequences postgresql_sequences} Data Source.
Types ¶
type DataPostgresqlSequences ¶
type DataPostgresqlSequences interface {
cdktf.TerraformDataSource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
Database() *string
SetDatabase(val *string)
DatabaseInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LikeAllPatterns() *[]*string
SetLikeAllPatterns(val *[]*string)
LikeAllPatternsInput() *[]*string
LikeAnyPatterns() *[]*string
SetLikeAnyPatterns(val *[]*string)
LikeAnyPatternsInput() *[]*string
// The tree node.
Node() constructs.Node
NotLikeAllPatterns() *[]*string
SetNotLikeAllPatterns(val *[]*string)
NotLikeAllPatternsInput() *[]*string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
RegexPattern() *string
SetRegexPattern(val *string)
RegexPatternInput() *string
Schemas() *[]*string
SetSchemas(val *[]*string)
SchemasInput() *[]*string
Sequences() DataPostgresqlSequencesSequencesList
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
ResetLikeAllPatterns()
ResetLikeAnyPatterns()
ResetNotLikeAllPatterns()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRegexPattern()
ResetSchemas()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Adds this resource to the terraform JSON output.
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/cyrilgdn/postgresql/1.25.0/docs/data-sources/sequences postgresql_sequences}.
func NewDataPostgresqlSequences ¶
func NewDataPostgresqlSequences(scope constructs.Construct, id *string, config *DataPostgresqlSequencesConfig) DataPostgresqlSequences
Create a new {@link https://registry.terraform.io/providers/cyrilgdn/postgresql/1.25.0/docs/data-sources/sequences postgresql_sequences} Data Source.
type DataPostgresqlSequencesConfig ¶
type DataPostgresqlSequencesConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The PostgreSQL database which will be queried for sequence names.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cyrilgdn/postgresql/1.25.0/docs/data-sources/sequences#database DataPostgresqlSequences#database}
Database *string `field:"required" json:"database" yaml:"database"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cyrilgdn/postgresql/1.25.0/docs/data-sources/sequences#id DataPostgresqlSequences#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Expression(s) which will be pattern matched against sequence names in the query using the PostgreSQL LIKE ALL operator.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cyrilgdn/postgresql/1.25.0/docs/data-sources/sequences#like_all_patterns DataPostgresqlSequences#like_all_patterns}
LikeAllPatterns *[]*string `field:"optional" json:"likeAllPatterns" yaml:"likeAllPatterns"`
// Expression(s) which will be pattern matched against sequence names in the query using the PostgreSQL LIKE ANY operator.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cyrilgdn/postgresql/1.25.0/docs/data-sources/sequences#like_any_patterns DataPostgresqlSequences#like_any_patterns}
LikeAnyPatterns *[]*string `field:"optional" json:"likeAnyPatterns" yaml:"likeAnyPatterns"`
// Expression(s) which will be pattern matched against sequence names in the query using the PostgreSQL NOT LIKE ALL operator.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cyrilgdn/postgresql/1.25.0/docs/data-sources/sequences#not_like_all_patterns DataPostgresqlSequences#not_like_all_patterns}
NotLikeAllPatterns *[]*string `field:"optional" json:"notLikeAllPatterns" yaml:"notLikeAllPatterns"`
// Expression which will be pattern matched against sequence names in the query using the PostgreSQL ~ (regular expression match) operator.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cyrilgdn/postgresql/1.25.0/docs/data-sources/sequences#regex_pattern DataPostgresqlSequences#regex_pattern}
RegexPattern *string `field:"optional" json:"regexPattern" yaml:"regexPattern"`
// The PostgreSQL schema(s) which will be queried for sequence names. Queries all schemas in the database by default.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cyrilgdn/postgresql/1.25.0/docs/data-sources/sequences#schemas DataPostgresqlSequences#schemas}
Schemas *[]*string `field:"optional" json:"schemas" yaml:"schemas"`
}
type DataPostgresqlSequencesSequences ¶
type DataPostgresqlSequencesSequences struct {
}
type DataPostgresqlSequencesSequencesList ¶
type DataPostgresqlSequencesSequencesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataPostgresqlSequencesSequencesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataPostgresqlSequencesSequencesList ¶
func NewDataPostgresqlSequencesSequencesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataPostgresqlSequencesSequencesList
type DataPostgresqlSequencesSequencesOutputReference ¶
type DataPostgresqlSequencesSequencesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DataType() *string
// Experimental.
Fqn() *string
InternalValue() *DataPostgresqlSequencesSequences
SetInternalValue(val *DataPostgresqlSequencesSequences)
ObjectName() *string
SchemaName() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataPostgresqlSequencesSequencesOutputReference ¶
func NewDataPostgresqlSequencesSequencesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataPostgresqlSequencesSequencesOutputReference
Source Files
¶
- DataPostgresqlSequences.go
- DataPostgresqlSequencesConfig.go
- DataPostgresqlSequencesSequences.go
- DataPostgresqlSequencesSequencesList.go
- DataPostgresqlSequencesSequencesList__checks.go
- DataPostgresqlSequencesSequencesOutputReference.go
- DataPostgresqlSequencesSequencesOutputReference__checks.go
- DataPostgresqlSequences__checks.go
- main.go