Documentation
¶
Index ¶
- func DataGoogleMemcacheInstance_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func DataGoogleMemcacheInstance_IsConstruct(x interface{}) *bool
- func DataGoogleMemcacheInstance_IsTerraformDataSource(x interface{}) *bool
- func DataGoogleMemcacheInstance_IsTerraformElement(x interface{}) *bool
- func DataGoogleMemcacheInstance_TfResourceType() *string
- func NewDataGoogleMemcacheInstanceMaintenancePolicyList_Override(d DataGoogleMemcacheInstanceMaintenancePolicyList, ...)
- func NewDataGoogleMemcacheInstanceMaintenancePolicyOutputReference_Override(d DataGoogleMemcacheInstanceMaintenancePolicyOutputReference, ...)
- func NewDataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList_Override(d DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList, ...)
- func NewDataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference_Override(...)
- func NewDataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList_Override(...)
- func NewDataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference_Override(...)
- func NewDataGoogleMemcacheInstanceMaintenanceScheduleList_Override(d DataGoogleMemcacheInstanceMaintenanceScheduleList, ...)
- func NewDataGoogleMemcacheInstanceMaintenanceScheduleOutputReference_Override(d DataGoogleMemcacheInstanceMaintenanceScheduleOutputReference, ...)
- func NewDataGoogleMemcacheInstanceMemcacheNodesList_Override(d DataGoogleMemcacheInstanceMemcacheNodesList, ...)
- func NewDataGoogleMemcacheInstanceMemcacheNodesOutputReference_Override(d DataGoogleMemcacheInstanceMemcacheNodesOutputReference, ...)
- func NewDataGoogleMemcacheInstanceMemcacheParametersList_Override(d DataGoogleMemcacheInstanceMemcacheParametersList, ...)
- func NewDataGoogleMemcacheInstanceMemcacheParametersOutputReference_Override(d DataGoogleMemcacheInstanceMemcacheParametersOutputReference, ...)
- func NewDataGoogleMemcacheInstanceNodeConfigList_Override(d DataGoogleMemcacheInstanceNodeConfigList, ...)
- func NewDataGoogleMemcacheInstanceNodeConfigOutputReference_Override(d DataGoogleMemcacheInstanceNodeConfigOutputReference, ...)
- func NewDataGoogleMemcacheInstance_Override(d DataGoogleMemcacheInstance, scope constructs.Construct, id *string, ...)
- type DataGoogleMemcacheInstance
- type DataGoogleMemcacheInstanceConfig
- type DataGoogleMemcacheInstanceMaintenancePolicy
- type DataGoogleMemcacheInstanceMaintenancePolicyList
- type DataGoogleMemcacheInstanceMaintenancePolicyOutputReference
- type DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindow
- type DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList
- type DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference
- type DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime
- type DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList
- type DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference
- type DataGoogleMemcacheInstanceMaintenanceSchedule
- type DataGoogleMemcacheInstanceMaintenanceScheduleList
- type DataGoogleMemcacheInstanceMaintenanceScheduleOutputReference
- type DataGoogleMemcacheInstanceMemcacheNodes
- type DataGoogleMemcacheInstanceMemcacheNodesList
- type DataGoogleMemcacheInstanceMemcacheNodesOutputReference
- type DataGoogleMemcacheInstanceMemcacheParameters
- type DataGoogleMemcacheInstanceMemcacheParametersList
- type DataGoogleMemcacheInstanceMemcacheParametersOutputReference
- type DataGoogleMemcacheInstanceNodeConfig
- type DataGoogleMemcacheInstanceNodeConfigList
- type DataGoogleMemcacheInstanceNodeConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataGoogleMemcacheInstance_GenerateConfigForImport ¶
func DataGoogleMemcacheInstance_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a DataGoogleMemcacheInstance resource upon running "cdktf plan <stack-name>".
func DataGoogleMemcacheInstance_IsConstruct ¶
func DataGoogleMemcacheInstance_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataGoogleMemcacheInstance_IsTerraformDataSource ¶
func DataGoogleMemcacheInstance_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataGoogleMemcacheInstance_IsTerraformElement ¶
func DataGoogleMemcacheInstance_IsTerraformElement(x interface{}) *bool
Experimental.
func DataGoogleMemcacheInstance_TfResourceType ¶
func DataGoogleMemcacheInstance_TfResourceType() *string
func NewDataGoogleMemcacheInstanceMaintenancePolicyList_Override ¶
func NewDataGoogleMemcacheInstanceMaintenancePolicyList_Override(d DataGoogleMemcacheInstanceMaintenancePolicyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleMemcacheInstanceMaintenancePolicyOutputReference_Override ¶
func NewDataGoogleMemcacheInstanceMaintenancePolicyOutputReference_Override(d DataGoogleMemcacheInstanceMaintenancePolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList_Override ¶
func NewDataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList_Override(d DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference_Override ¶
func NewDataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference_Override(d DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList_Override ¶
func NewDataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList_Override(d DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference_Override ¶
func NewDataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference_Override(d DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleMemcacheInstanceMaintenanceScheduleList_Override ¶
func NewDataGoogleMemcacheInstanceMaintenanceScheduleList_Override(d DataGoogleMemcacheInstanceMaintenanceScheduleList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleMemcacheInstanceMaintenanceScheduleOutputReference_Override ¶
func NewDataGoogleMemcacheInstanceMaintenanceScheduleOutputReference_Override(d DataGoogleMemcacheInstanceMaintenanceScheduleOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleMemcacheInstanceMemcacheNodesList_Override ¶
func NewDataGoogleMemcacheInstanceMemcacheNodesList_Override(d DataGoogleMemcacheInstanceMemcacheNodesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleMemcacheInstanceMemcacheNodesOutputReference_Override ¶
func NewDataGoogleMemcacheInstanceMemcacheNodesOutputReference_Override(d DataGoogleMemcacheInstanceMemcacheNodesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleMemcacheInstanceMemcacheParametersList_Override ¶
func NewDataGoogleMemcacheInstanceMemcacheParametersList_Override(d DataGoogleMemcacheInstanceMemcacheParametersList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleMemcacheInstanceMemcacheParametersOutputReference_Override ¶
func NewDataGoogleMemcacheInstanceMemcacheParametersOutputReference_Override(d DataGoogleMemcacheInstanceMemcacheParametersOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleMemcacheInstanceNodeConfigList_Override ¶
func NewDataGoogleMemcacheInstanceNodeConfigList_Override(d DataGoogleMemcacheInstanceNodeConfigList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleMemcacheInstanceNodeConfigOutputReference_Override ¶
func NewDataGoogleMemcacheInstanceNodeConfigOutputReference_Override(d DataGoogleMemcacheInstanceNodeConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleMemcacheInstance_Override ¶
func NewDataGoogleMemcacheInstance_Override(d DataGoogleMemcacheInstance, scope constructs.Construct, id *string, config *DataGoogleMemcacheInstanceConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/7.32.0/docs/data-sources/google_memcache_instance google_memcache_instance} Data Source.
Types ¶
type DataGoogleMemcacheInstance ¶
type DataGoogleMemcacheInstance interface {
cdktf.TerraformDataSource
AuthorizedNetwork() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
DeletionProtection() cdktf.IResolvable
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DiscoveryEndpoint() *string
DisplayName() *string
EffectiveLabels() cdktf.StringMap
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Labels() cdktf.StringMap
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MaintenancePolicy() DataGoogleMemcacheInstanceMaintenancePolicyList
MaintenanceSchedule() DataGoogleMemcacheInstanceMaintenanceScheduleList
MemcacheFullVersion() *string
MemcacheNodes() DataGoogleMemcacheInstanceMemcacheNodesList
MemcacheParameters() DataGoogleMemcacheInstanceMemcacheParametersList
MemcacheVersion() *string
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
NodeConfig() DataGoogleMemcacheInstanceNodeConfigList
NodeCount() *float64
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
Region() *string
SetRegion(val *string)
RegionInput() *string
ReservedIpRangeId() *[]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Zones() *[]*string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetRegion()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Adds this resource to the terraform JSON output.
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/7.32.0/docs/data-sources/google_memcache_instance google_memcache_instance}.
func NewDataGoogleMemcacheInstance ¶
func NewDataGoogleMemcacheInstance(scope constructs.Construct, id *string, config *DataGoogleMemcacheInstanceConfig) DataGoogleMemcacheInstance
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/7.32.0/docs/data-sources/google_memcache_instance google_memcache_instance} Data Source.
type DataGoogleMemcacheInstanceConfig ¶
type DataGoogleMemcacheInstanceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The resource name of the instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/7.32.0/docs/data-sources/google_memcache_instance#name DataGoogleMemcacheInstance#name}
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/7.32.0/docs/data-sources/google_memcache_instance#id DataGoogleMemcacheInstance#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/7.32.0/docs/data-sources/google_memcache_instance#project DataGoogleMemcacheInstance#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// The region of the Memcache instance. If it is not provided, the provider region is used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/7.32.0/docs/data-sources/google_memcache_instance#region DataGoogleMemcacheInstance#region}
Region *string `field:"optional" json:"region" yaml:"region"`
}
type DataGoogleMemcacheInstanceMaintenancePolicy ¶
type DataGoogleMemcacheInstanceMaintenancePolicy struct {
}
type DataGoogleMemcacheInstanceMaintenancePolicyList ¶
type DataGoogleMemcacheInstanceMaintenancePolicyList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleMemcacheInstanceMaintenancePolicyOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleMemcacheInstanceMaintenancePolicyList ¶
func NewDataGoogleMemcacheInstanceMaintenancePolicyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleMemcacheInstanceMaintenancePolicyList
type DataGoogleMemcacheInstanceMaintenancePolicyOutputReference ¶
type DataGoogleMemcacheInstanceMaintenancePolicyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CreateTime() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Description() *string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleMemcacheInstanceMaintenancePolicy
SetInternalValue(val *DataGoogleMemcacheInstanceMaintenancePolicy)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UpdateTime() *string
WeeklyMaintenanceWindow() DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleMemcacheInstanceMaintenancePolicyOutputReference ¶
func NewDataGoogleMemcacheInstanceMaintenancePolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleMemcacheInstanceMaintenancePolicyOutputReference
type DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindow ¶
type DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindow struct {
}
type DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList ¶
type DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList ¶
func NewDataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList
type DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference ¶
type DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Day() *string
Duration() *string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindow
SetInternalValue(val *DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindow)
StartTime() DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference ¶
func NewDataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference
type DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime ¶
type DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime struct {
}
type DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList ¶
type DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList ¶
func NewDataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList
type DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference ¶
type DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Hours() *float64
InternalValue() *DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime
SetInternalValue(val *DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime)
Minutes() *float64
Nanos() *float64
Seconds() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference ¶
func NewDataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference
type DataGoogleMemcacheInstanceMaintenanceSchedule ¶
type DataGoogleMemcacheInstanceMaintenanceSchedule struct {
}
type DataGoogleMemcacheInstanceMaintenanceScheduleList ¶
type DataGoogleMemcacheInstanceMaintenanceScheduleList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleMemcacheInstanceMaintenanceScheduleOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleMemcacheInstanceMaintenanceScheduleList ¶
func NewDataGoogleMemcacheInstanceMaintenanceScheduleList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleMemcacheInstanceMaintenanceScheduleList
type DataGoogleMemcacheInstanceMaintenanceScheduleOutputReference ¶
type DataGoogleMemcacheInstanceMaintenanceScheduleOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EndTime() *string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleMemcacheInstanceMaintenanceSchedule
SetInternalValue(val *DataGoogleMemcacheInstanceMaintenanceSchedule)
ScheduleDeadlineTime() *string
StartTime() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleMemcacheInstanceMaintenanceScheduleOutputReference ¶
func NewDataGoogleMemcacheInstanceMaintenanceScheduleOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleMemcacheInstanceMaintenanceScheduleOutputReference
type DataGoogleMemcacheInstanceMemcacheNodes ¶
type DataGoogleMemcacheInstanceMemcacheNodes struct {
}
type DataGoogleMemcacheInstanceMemcacheNodesList ¶
type DataGoogleMemcacheInstanceMemcacheNodesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleMemcacheInstanceMemcacheNodesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleMemcacheInstanceMemcacheNodesList ¶
func NewDataGoogleMemcacheInstanceMemcacheNodesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleMemcacheInstanceMemcacheNodesList
type DataGoogleMemcacheInstanceMemcacheNodesOutputReference ¶
type DataGoogleMemcacheInstanceMemcacheNodesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Host() *string
InternalValue() *DataGoogleMemcacheInstanceMemcacheNodes
SetInternalValue(val *DataGoogleMemcacheInstanceMemcacheNodes)
NodeId() *string
Port() *float64
State() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Zone() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleMemcacheInstanceMemcacheNodesOutputReference ¶
func NewDataGoogleMemcacheInstanceMemcacheNodesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleMemcacheInstanceMemcacheNodesOutputReference
type DataGoogleMemcacheInstanceMemcacheParameters ¶
type DataGoogleMemcacheInstanceMemcacheParameters struct {
}
type DataGoogleMemcacheInstanceMemcacheParametersList ¶
type DataGoogleMemcacheInstanceMemcacheParametersList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleMemcacheInstanceMemcacheParametersOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleMemcacheInstanceMemcacheParametersList ¶
func NewDataGoogleMemcacheInstanceMemcacheParametersList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleMemcacheInstanceMemcacheParametersList
type DataGoogleMemcacheInstanceMemcacheParametersOutputReference ¶
type DataGoogleMemcacheInstanceMemcacheParametersOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *DataGoogleMemcacheInstanceMemcacheParameters
SetInternalValue(val *DataGoogleMemcacheInstanceMemcacheParameters)
Params() cdktf.StringMap
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleMemcacheInstanceMemcacheParametersOutputReference ¶
func NewDataGoogleMemcacheInstanceMemcacheParametersOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleMemcacheInstanceMemcacheParametersOutputReference
type DataGoogleMemcacheInstanceNodeConfig ¶
type DataGoogleMemcacheInstanceNodeConfig struct {
}
type DataGoogleMemcacheInstanceNodeConfigList ¶
type DataGoogleMemcacheInstanceNodeConfigList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleMemcacheInstanceNodeConfigOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleMemcacheInstanceNodeConfigList ¶
func NewDataGoogleMemcacheInstanceNodeConfigList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleMemcacheInstanceNodeConfigList
type DataGoogleMemcacheInstanceNodeConfigOutputReference ¶
type DataGoogleMemcacheInstanceNodeConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CpuCount() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleMemcacheInstanceNodeConfig
SetInternalValue(val *DataGoogleMemcacheInstanceNodeConfig)
MemorySizeMb() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleMemcacheInstanceNodeConfigOutputReference ¶
func NewDataGoogleMemcacheInstanceNodeConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleMemcacheInstanceNodeConfigOutputReference
Source Files
¶
- DataGoogleMemcacheInstance.go
- DataGoogleMemcacheInstanceConfig.go
- DataGoogleMemcacheInstanceMaintenancePolicy.go
- DataGoogleMemcacheInstanceMaintenancePolicyList.go
- DataGoogleMemcacheInstanceMaintenancePolicyList__checks.go
- DataGoogleMemcacheInstanceMaintenancePolicyOutputReference.go
- DataGoogleMemcacheInstanceMaintenancePolicyOutputReference__checks.go
- DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindow.go
- DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList.go
- DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList__checks.go
- DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference.go
- DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference__checks.go
- DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime.go
- DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList.go
- DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeList__checks.go
- DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference.go
- DataGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference__checks.go
- DataGoogleMemcacheInstanceMaintenanceSchedule.go
- DataGoogleMemcacheInstanceMaintenanceScheduleList.go
- DataGoogleMemcacheInstanceMaintenanceScheduleList__checks.go
- DataGoogleMemcacheInstanceMaintenanceScheduleOutputReference.go
- DataGoogleMemcacheInstanceMaintenanceScheduleOutputReference__checks.go
- DataGoogleMemcacheInstanceMemcacheNodes.go
- DataGoogleMemcacheInstanceMemcacheNodesList.go
- DataGoogleMemcacheInstanceMemcacheNodesList__checks.go
- DataGoogleMemcacheInstanceMemcacheNodesOutputReference.go
- DataGoogleMemcacheInstanceMemcacheNodesOutputReference__checks.go
- DataGoogleMemcacheInstanceMemcacheParameters.go
- DataGoogleMemcacheInstanceMemcacheParametersList.go
- DataGoogleMemcacheInstanceMemcacheParametersList__checks.go
- DataGoogleMemcacheInstanceMemcacheParametersOutputReference.go
- DataGoogleMemcacheInstanceMemcacheParametersOutputReference__checks.go
- DataGoogleMemcacheInstanceNodeConfig.go
- DataGoogleMemcacheInstanceNodeConfigList.go
- DataGoogleMemcacheInstanceNodeConfigList__checks.go
- DataGoogleMemcacheInstanceNodeConfigOutputReference.go
- DataGoogleMemcacheInstanceNodeConfigOutputReference__checks.go
- DataGoogleMemcacheInstance__checks.go
- main.go